@@ -14,19 +14,14 @@
 
 #include "marble_export.h"
 
-#include <QSize>
-#include <QRegion>
-
 // Marble
 #include "MarbleGlobal.h"
 #include "ClipPainter.h"
 
-
+#include <QSizeF>
 class QImage;
 class QPaintDevice;
-class QPolygonF;
-class QRect;
-class QRectF;
+class QRegion;
 class QString;
 
 
@@ -133,7 +128,7 @@ class MARBLE_EXPORT GeoPainter : public ClipPainter
     chosen for the painter is used to paint the background of the bubble
 
     The optional parameters which describe the layout of the bubble are
-    similar to those used by QPainter::drawRoundRect().
+    similar to those used by QPainter::drawRoundedRect().
     Unlike in QPainter the rounded corners are not specified in percentage
     but in pixels to provide for optimal aesthetics.
     By choosing a positive or negative bubbleOffset it's possible to
@@ -226,8 +221,8 @@ class MARBLE_EXPORT GeoPainter : public ClipPainter
     further influenced.
 */
     void drawText ( const GeoDataCoordinates & position, const QString & text,
-                    int xOffset = 0, int yOffset = 0,
-                    int width = 0, int height = 0,
+                    qreal xOffset = 0.0, qreal yOffset = 0.0,
+                    qreal width = 0.0, qreal height = 0.0,
                     const QTextOption & option = QTextOption() );
 
     
@@ -294,6 +289,20 @@ class MARBLE_EXPORT GeoPainter : public ClipPainter
     void drawPixmap ( const GeoDataCoordinates & centerPosition,
                       const QPixmap & pixmap /*, bool isGeoProjected = false */ );
 
+/*!
+    \brief Creates a region for a rectangle for a pixmap at a given position.
+
+    A QRegion object is created that represents the area covered by
+    GeoPainter::drawPixmap(). This can be used e.g. for input event handling
+    for objects that have been painted using GeoPainter::drawPixmap().
+
+    The \a margin allows to extrude the QRegion by "margin" pixels on every side.
+
+    \see GeoDataCoordinates
+*/
+    QRegion regionFromPixmapRect(const GeoDataCoordinates &centerCoordinates,
+                                 int width, int height,
+                                 int margin = 0) const;
 
 /*!
     \brief Draws a given line string (a "polyline").
@@ -446,9 +455,9 @@ class MARBLE_EXPORT GeoPainter : public ClipPainter
 
     \see GeoDataCoordinates
 */
-    void drawRoundRect ( const GeoDataCoordinates & centerPosition,
-                         int width, int height,
-                         int xRnd = 25, int yRnd = 25 );
+    void drawRoundedRect(const GeoDataCoordinates &centerPosition,
+                         qreal width, qreal height,
+                         qreal xRnd = 25.0, qreal yRnd = 25.0);
 
 
 
